@@ -10,6 +10,7 @@ import sys
 import subprocess
 import tempfile
 import math
+import warnings
 
 try:
     import ziamath  # type: ignore
@@ -21,8 +22,58 @@ from ..util import Point
 from . import svgtext
 
 
-textmode: TextMode = 'path' if ziamath is not None else 'text'
-svg2mode: bool = True
+class Config:
+    ''' Configuration options for SVG backend '''
+    _text: TextMode = 'path' if ziamath is not None else 'text'
+
+    @property
+    def text(self) -> TextMode:
+        ''' One of 'path' or 'text'. In 'text' mode, text is drawn
+            as SVG <text> elements and will be searchable in the
+            SVG, however it may render differently on systems without
+            the same fonts installed. In 'path' mode, text is
+            converted to SVG <path> elements and will render
+            independently of any fonts on the system. Path mode
+            enables full rendering of math expressions, but also
+            requires the ziafont/ziamath packages.
+        '''
+        return self._text
+
+    @text.setter
+    def text(self, value: TextMode) -> None:
+        if value == 'path' and ziamath is None:
+            raise ValueError('Path mode requires ziamath package')
+        if value not in ['path', 'text']:
+            raise ValueError('text mode must be "path" or "text".')
+        self._text = value
+    
+    @property
+    def svg2(self) -> bool:
+        ''' Use SVG2.0. Disable for better browser compatibility
+            at the expense of SVG size.
+        '''
+        if ziamath is not None:
+            return ziamath.config.svg2
+        return None
+
+    @svg2.setter
+    def svg2(self, value: bool) -> None:
+        if ziamath is None:
+            raise ValueError('SVG2 mode requires ziamath package')
+        ziamath.config.svg2 = value
+
+    @property
+    def precision(self) -> float:
+        ''' Decimal precision for SVG coordinates '''
+        return ziamath.config.precision
+
+    @precision.setter
+    def precision(self, value: float) -> None:
+        ziamath.config.precision = value
+
+
+config = Config()
+
 
 hatchpattern = '''<defs><pattern id="hatch" patternUnits="userSpaceOnUse" width="4" height="4">
 <path d="M-1,1 l2,-2 M0,4 l4,-4 M3,5 l2,-2" style="stroke:black; stroke-width:.5" /></pattern></defs>'''
@@ -44,12 +95,9 @@ def settextmode(mode: TextMode, svg2: bool=True) -> None:
             mode: Text Mode.
             svg2: Use SVG2.0. Disable for better compatibility.
     '''
-    if mode == 'path' and ziamath is None:
-        raise ValueError('Path mode requires ziamath package')
-    global textmode
-    global svg2mode
-    textmode = mode
-    svg2mode = svg2
+    warnings.warn('settextmode is deprecated. Use schemdraw.svgconfig',  DeprecationWarning)
+    config.svg2 = svg2
+    config.text = mode
 
 
 def isnotebook():
@@ -121,7 +169,7 @@ def text_size(text: str, font: str='Arial', size: float=16) -> tuple[float, floa
         lines = text.splitlines()
         maths = []
         for line in lines:
-            maths.append(ziamath.Math.fromlatextext(line, size=size, mathstyle=font, textstyle=font, svg2=svg2mode))
+            maths.append(ziamath.Math.fromlatextext(line, size=size, mathstyle=font, textstyle=font))
         sizes = [m.getsize() for m in maths]
         w: float = max([s[0] for s in sizes])
         h: float = sum([s[1] for s in sizes])
@@ -205,6 +253,7 @@ class Figure:
 
     def text(self, s: str, x: float, y: float, color: str='black',
              fontsize: float=14, fontfamily: str='sans-serif',
+             mathfont: str=None,
              rotation: float=0, halign: Halign='center',
              valign: Valign='center',
              rotation_mode: RotationMode='anchor', clip: BBox=None, zorder: int=3) -> None:
@@ -213,42 +262,17 @@ class Figure:
             return
 
         y += fontsize/72*2/6  # A bit of baseline shift to match MPL
-        x, y = self.xform(x, y)
-
-        if ziamath and textmode == 'path':
+        x0, y0 = self.xform(x, y)
+        x, y = x0, y0
+        
+        if ziamath and config.text == 'path':
             texttag = ET.Element('g')
-            if fontfamily.lower() in ['sans-serif', 'Arial']:
-                fontfamily = 'sans'
-
-            lines = s.splitlines()
-            maths = []
-            for i, line in enumerate(lines):
-                maths.append(ziamath.Math.fromlatextext(
-                    line, size=fontsize, mathstyle=fontfamily, textstyle=fontfamily,
-                    svg2=svg2mode))
-
-            dys = [max(m.node.bbox.ymax*1.25, 0) for m in maths]
-            if len(lines) > 1:
-                topbase = sum(dys[:-1])
-                if valign == 'bottom':
-                    y -= topbase
-                elif valign == 'center':
-                    y -= topbase/2 - fontsize/2
-                elif valign == 'top':
-                    y += topbase
-            elif valign == 'top':
-                y += dys[0]
-            elif valign == 'center':
-                y += dys[0]/2
-
-            yi = y
-            for dy, m in zip(dys, maths):
-                m.drawon(x, yi, texttag, halign=halign, valign='baseline', color=color)
-                yi += dy
-
-            if rotation:
-                texttag.set('transform', f'rotate({-rotation} {x} {y})')
-
+            
+            ztext = ziamath.Text(s, textfont=fontfamily, mathfont=mathfont,
+                         size=fontsize, linespacing=1, color=color,
+                         rotation=rotation, rotation_mode=rotation_mode)
+            ztext.drawon(texttag, x0, y0,
+                         halign=halign, valign=valign)
         else:
             texttag = svgtext.text_tosvg(s, x, y, font=fontfamily, size=fontsize,
                                          halign=halign, valign=valign, color=color,
@@ -289,7 +313,7 @@ class Figure:
         self.svgelements.append((zorder, et))
 
     def arrow(self, xy: Sequence[float], theta: float,
-              arrowwidth: float=.2, arrowlength: float=.2,
+              arrowwidth: float=.15, arrowlength: float=.25,
               color: str='black', lw: float=2, clip: BBox=None, zorder: int=1) -> None:
         ''' Draw an arrowhead '''
         x, y = self.xform(*xy)
@@ -357,11 +381,17 @@ class Figure:
                 theta = math.degrees(math.atan2(delta.y, delta.x))
                 self.arrow(p[0], theta, color=color, lw=1, zorder=zorder,
                            clip=clip, arrowlength=arrowlength, arrowwidth=arrowwidth)
+            elif arrow.startswith('o'):
+                self.circle(p[0], radius=arrowwidth/2, color=color, fill=color, lw=0,
+                           clip=clip, zorder=zorder)
             if '>' in arrow:
                 delta = p[-1] - p[-2]
                 theta = math.degrees(math.atan2(delta.y, delta.x))
                 self.arrow(p[-1], theta, color=color, lw=1, zorder=zorder,
                            clip=clip, arrowlength=arrowlength, arrowwidth=arrowwidth)
+            elif arrow.endswith('o'):
+                self.circle(p[-1], radius=arrowwidth/2, color=color, fill=color, lw=0,
+                           clip=clip, zorder=zorder)
 
     def arc(self, center: Sequence[float], width: float, height: float,
             theta1: float=0, theta2: float=90, angle: float=0,
@@ -405,9 +435,7 @@ class Figure:
             et.set('ry', str(height/2))
             if angle != 0:
                 et.set('transform', f'rotate({angle} {centerx} {centery})')
-            et.set('stroke', color)
-            et.set('stroke-width', str(lw))
-            et.set('fill', 'none')
+            et.set('style', getstyle(color=color, ls=ls, lw=lw))
             self.addclip(et, clip)
             self.svgelements.append((zorder, et))
 
@@ -417,9 +445,7 @@ class Figure:
             d = f'M {startx} {starty}'
             d += f' a {width/2} {height/2} {angle} {flags} {dx} {dy}'
             et.set('d', d)
-            et.set('stroke', color)
-            et.set('stroke-width', str(lw))
-            et.set('fill', 'none')
+            et.set('style', getstyle(color=color, ls=ls, lw=lw))
             self.addclip(et, clip)
             self.svgelements.append((zorder, et))
 
