@@ -7,7 +7,7 @@ from dataclasses import dataclass
 import warnings
 import math
 
-from ..segments import SegmentText, BBox, SegmentType
+from ..segments import SegmentText, SegmentCircle, BBox, SegmentType
 from ..transform import Transform
 from .. import util
 from ..util import Point
@@ -15,6 +15,7 @@ from ..types import XY, Linestyle, Align, Halign, Valign, LabelLoc
 
 gap = (math.nan, math.nan)  # Put a gap in a path
 
+
 Figure = None
 def _set_elm_backend(figureclass):
     global Figure
@@ -31,6 +32,7 @@ class Label:
     rotate: bool | float = False  # True=same angle as element; False = 0
     fontsize: float | None = None
     font: str | None = None
+    mathfont: str | None = None
     color: str | None = None
 
 
@@ -122,15 +124,22 @@ class Element:
         self._userparams['drop'] = drop
         return self
 
-    def at(self, xy: XY | tuple['Element', str]) -> 'Element':
+    def at(self, xy: XY | tuple['Element', str], dx: float=0, dy: float=0) -> 'Element':
         ''' Set the element xy position
 
             Args:
                 xy: (x,y) position or tuple of (Element, anchorname)
+                
         '''
+        xy = Point(xy)
         if 'at' in self._userparams:
             warnings.warn(f"Duplicate `at` parameter in element: `{self._userparams['at']}` changed to `{xy}`.")
-        self._userparams['at'] = xy
+        if isinstance(xy[1], str):
+            self._userparams['at'] = xy
+            if dx != 0 or dy != 0:
+                raise ValueError('dx and dy must be zero for anchorname XY')
+        else:
+            self._userparams['at'] = Point((xy.x + dx, xy.y + dy))
         return self
 
     def scale(self, scale: float=1) -> 'Element':
@@ -235,6 +244,7 @@ class Element:
               rotate: bool | float=False,
               fontsize: float=None,
               font: str=None,
+              mathfont: str=None,
               color: str=None):
         ''' Add a label to the Element.
 
@@ -249,7 +259,8 @@ class Element:
                 rotate: True to rotate label with element, or specify rotation
                     angle in degrees
                 fontsize: Size of label font
-                font: Name/font-family of label
+                font: Name/font-family of label text
+                mathfont: Name/font-family of math text
                 color: Color of label
         '''
         if halign is None and valign is None:
@@ -260,7 +271,7 @@ class Element:
             rotate = 0
         elif isinstance(rotate, bool):
             rotate = True
-        self._userlabels.append(Label(label, loc, ofst, align, rotate, fontsize, font, color))
+        self._userlabels.append(Label(label, loc, ofst, align, rotate, fontsize, font, mathfont, color))
         return self
 
     def _buildparams(self) -> None:
@@ -302,7 +313,7 @@ class Element:
             self._buildparams()
 
         anchor = self._cparams.get('anchor', None)
-        zoom = self._cparams.get('zoom', 1)
+        zoom = self._cparams.get('zoom', self._cparams.get('scale', 1))
         xy = self._cparams.get('at', dwgxy)
 
         # Get bounds of element, used for positioning user labels
@@ -355,7 +366,8 @@ class Element:
                 rotate = label.rotate
             self._place_label(label.label, loc=label.loc, ofst=label.ofst,
                               align=label.align, rotation=rotate,
-                              font=label.font, fontsize=label.fontsize,
+                              font=label.font, mathfont=label.mathfont,
+                              fontsize=label.fontsize,
                               color=label.color)
 
         # Add element-specific anchors
@@ -368,7 +380,7 @@ class Element:
             # User specified as anchor position
             self.absdrop = self.transform.transform(self.anchors[drop]), theta
         elif drop is not None and self._cparams.get('move_cur', True):
-            if self.params.get('droptheta', None):
+            if self.params.get('droptheta', None) is not None:
                 # Element-specified drop angle
                 self.absdrop = self.transform.transform(drop), self.params.get('droptheta')
             elif self.params.get('theta', None) == 0:
@@ -436,7 +448,7 @@ class Element:
     def _place_label(self, label: str, loc: LabelLoc=None,
                      ofst: XY | float | None=None, align: Align=(None, None),
                      rotation: float=0, fontsize: float=None,
-                     font: str=None, color: str=None) -> None:
+                     font: str=None, mathfont: str=None, color: str=None) -> None:
         ''' Adds the label Segment to the element, AFTER element placement
 
             Args:
@@ -452,6 +464,7 @@ class Element:
                 rotation: Rotation angle (degrees)
                 fontsize: Font size
                 font: Font family
+                mathfont: Math font family
                 color: Label text color
         '''
         rotation = (rotation + 360) % 360
@@ -540,7 +553,10 @@ class Element:
                         ofsty = 0
 
                     align = (align[0] or alignH, align[1] or alignV)
-                    rotalignidx = (rotalign.index(align) + round((th/360)*8)) % 8
+                    try:
+                        rotalignidx = (rotalign.index(align) + round((th/360)*8)) % 8
+                    except ValueError:
+                        rotalignidx = 0
                     if ofst is None and not isinstance(label, (tuple, list)):
                         ofst = [ofstx, ofsty]
 
@@ -562,12 +578,15 @@ class Element:
             args['fontsize'] = fontsize
         if font is not None:
             args['font'] = font
+        if mathfont is not None:
+            args['mathfont'] = mathfont
         if color is not None:
             args['color'] = color
 
         lblparams = dict(ChainMap(args, self._cparams))
         lblparams = {'color': lblparams.get('color'),
                      'font': lblparams.get('font'),
+                     'mathfont': lblparams.get('mathfont'),
                      'fontsize': lblparams.get('fontsize', 14),
                      'align': align,
                      'rotation': rotation}
@@ -682,9 +701,16 @@ class Element2Term(Element):
             * center
             * end
     '''
-    def to(self, xy: XY) -> 'Element2Term':
-        ''' Sets ending position of element '''
-        self._userparams['to'] = xy
+    def to(self, xy: XY, dx: float=0, dy: float=0) -> 'Element2Term':
+        ''' Sets ending position of element
+
+            Args:
+                xy: Ending position of element
+                dx: X-offset from xy position
+                dy: Y-offset from xy position
+        '''
+        xy = Point(xy)
+        self._userparams['to'] = Point((xy.x + dx, xy.y + dy))
         return self
 
     def tox(self, x: float | XY | Element) -> 'Element2Term':
@@ -697,6 +723,42 @@ class Element2Term(Element):
         self._userparams['toy'] = y
         return self
 
+    def up(self, length: float=None) -> 'Element':
+        ''' Set the direction to up '''
+        if 'd' in self._userparams:
+            warnings.warn(f"Duplicated direction parameter in element. `{self._userparams['d']}` changed to `up`.")
+        self._userparams['d'] = 'up'
+        if length:
+            self._userparams['l'] = length
+        return self
+
+    def down(self, length: float=None) -> 'Element':
+        ''' Set the direction to down '''
+        if 'd' in self._userparams:
+            warnings.warn(f"Duplicated direction parameter in element. `{self._userparams['d']}` changed to `down`.")
+        self._userparams['d'] = 'down'
+        if length:
+            self._userparams['l'] = length
+        return self
+
+    def left(self, length: float=None) -> 'Element':
+        ''' Set the direction to left '''
+        if 'd' in self._userparams:
+            warnings.warn(f"Duplicated direction parameter in element. `{self._userparams['d']}` changed to `left`.")
+        self._userparams['d'] = 'left'
+        if length:
+            self._userparams['l'] = length
+        return self
+
+    def right(self, length: float=None) -> 'Element':
+        ''' Set the direction to right '''
+        if 'd' in self._userparams:
+            warnings.warn(f"Duplicated direction parameter in element. `{self._userparams['d']}` changed to `right`.")
+        self._userparams['d'] = 'right'
+        if length:
+            self._userparams['l'] = length
+        return self
+
     def length(self, length: float) -> 'Element2Term':
         ''' Sets total length of element '''
         self._userparams['l'] = length
@@ -709,6 +771,16 @@ class Element2Term(Element):
         self._userparams['endpts'] = (start, end)
         return self
 
+    def dot(self, open: bool=False) -> 'Element2Term':
+        ''' Add a dot to the end of the element '''
+        self._userparams['dot'] = True if not open else 'open'
+        return self
+
+    def idot(self, open: bool=False) -> 'Element2Term':
+        ''' Add a dot to the input/start of the element '''
+        self._userparams['idot'] = True if not open else 'open'
+        return self
+
     def _place(self, dwgxy: XY, dwgtheta: float, **dwgparams) -> tuple[Point, float]:
         ''' Calculate element placement, adding lead extensions '''
         self._dwgparams = dwgparams
@@ -721,21 +793,21 @@ class Element2Term(Element):
         tox = self._cparams.get('tox', None)
         toy = self._cparams.get('toy', None)
         anchor = self._cparams.get('anchor', None)
-        zoom = self._cparams.get('zoom', 1)
-        xy = self._cparams.get('at', dwgxy)
+        zoom = self._cparams.get('zoom', self._cparams.get('scale', 1))
+        xy = Point(self._cparams.get('at', dwgxy))
 
         # set up transformation
         theta = self._cparams.get('theta', dwgtheta)
         if endpts is not None:
             theta = util.angle(endpts[0], endpts[1])
+        elif to is not None:
+            theta = util.angle(xy, to)
         elif self._cparams.get('d') is not None:
             d = self._cparams.get('d')
             if str(d).lstrip('-').isnumeric():
                 theta = d
             else:
                 theta = {'u': 90, 'r': 0, 'l': 180, 'd': 270}[d[0].lower()]  # type: ignore
-        elif to is not None:
-            theta = util.angle(xy, to)
 
         # Get offset to element position within drawing (global shift)
         if endpts is not None:
@@ -754,6 +826,7 @@ class Element2Term(Element):
                 x = tox[0]
             endpt = [x, xy[1]]
             totlen = util.dist(xy, endpt)
+            theta = 180 if xy.x > x else 0
         elif toy is not None:
             # Allow either full coordinate (only keeping y), or just a y value
             if isinstance(toy, (int, float)):
@@ -762,12 +835,15 @@ class Element2Term(Element):
                 y = toy[1]
             endpt = [xy[0], y]
             totlen = util.dist(xy, endpt)
+            theta = -90 if xy.y > y else 90
 
+        self.anchors['istart'] = self.segments[0].path[0]  # type: ignore
+        self.anchors['iend'] = self.segments[0].path[-1]  # type: ignore
         if self._cparams.get('extend', True):
             in_path = self.segments[0].path  # type: ignore
             dz = util.delta(in_path[-1], in_path[0])   # Defined delta of path
             in_len = math.hypot(*dz)    # Defined length of path
-            lead_len = (totlen - in_len)/2
+            lead_len = (totlen - in_len*zoom)/2 / zoom
 
             if lead_len > 0:  # Don't make element shorter
                 start = Point(in_path[0]) - Point((lead_len, 0))
@@ -788,11 +864,18 @@ class Element2Term(Element):
                 elif getattr(self.segments[i], 'endref', None) == 'start':
                     xform = Transform(0, start)
                     self.segments[i] = self.segments[i].xform(xform)
+        else:
+            start = Point(self.segments[0].path[0])  # type: ignore
+            end = Point(self.segments[0].path[-1])  # type: ignore
 
-        self.anchors['start'] = Point(start)
-        self.anchors['end'] = Point(end)
-        self.anchors['center'] = (start+end)/2
+        if self._cparams.get('dot', False):
+            fill: Union[bool, str] = 'bg' if self._cparams['dot'] == 'open' else True
+            self.segments.append(SegmentCircle(end, radius=0.075, fill=fill, zorder=3))
+        if self._cparams.get('idot', False):
+            fill = 'bg' if self._cparams['idot'] == 'open' else True
+            self.segments.append(SegmentCircle(start, radius=0.075, fill=fill, zorder=3))
 
+        self._place_anchors(start, end)
         if anchor is not None:
             self._localshift = self._localshift-Point(self.anchors[anchor])
         transform = Transform(theta, xy, self._localshift, zoom=zoom)
@@ -809,3 +892,9 @@ class Element2Term(Element):
 
         self.params['drop'] = end
         return super()._place(xy, theta, **dwgparams)
+
+    def _place_anchors(self, start, end):
+        ''' Allow positioning anchors before the element is placed '''
+        self.anchors['start'] = Point(start)
+        self.anchors['end'] = Point(end)
+        self.anchors['center'] = (start+end)/2
