@@ -21,8 +21,8 @@ class Switch(Element2Term):
         super().__init__(*d, **kwargs)
         self.segments.append(Segment(
             [(0, 0), gap, (sw_dot_r*2, .1), (.8, .45), gap, (1, 0)]))
-        self.segments.append(SegmentCircle((sw_dot_r, 0), sw_dot_r))
-        self.segments.append(SegmentCircle((1-sw_dot_r, 0), sw_dot_r))
+        self.segments.append(SegmentCircle((sw_dot_r, 0), sw_dot_r, fill='bg', zorder=3))
+        self.segments.append(SegmentCircle((1-sw_dot_r, 0), sw_dot_r, fill='bg', zorder=3))
         if action == 'open':
             self.segments.append(SegmentArc((.4, .1), width=.5, height=.75,
                                             theta1=-10, theta2=70,
@@ -46,10 +46,10 @@ class SwitchSpdt(Switch):
     '''
     def __init__(self, *d, action: ActionType=None, **kwargs):
         super().__init__(*d, action=action, **kwargs)
-        self.segments.append(SegmentCircle((1-sw_dot_r, .7), sw_dot_r))
-        self.anchors['a'] = Point((0, 0))
-        self.anchors['b'] = Point((1, 0))
-        self.anchors['c'] = Point((1, .7))
+        self.segments.append(SegmentCircle((1-sw_dot_r, .7), sw_dot_r, fill='bg', zorder=3))
+        self.anchors['a'] = Point((sw_dot_r, 0))
+        self.anchors['b'] = Point((1-sw_dot_r, 0))
+        self.anchors['c'] = Point((1-sw_dot_r, .7))
 
 
 class SwitchSpdt2(Element):
@@ -67,12 +67,13 @@ class SwitchSpdt2(Element):
         super().__init__(*d, action=action, **kwargs)
         self.segments.append(Segment([(0, 0), gap, (sw_dot_r*2, .1),
                                       (.7, .25), gap, (1, .4)]))
-        self.segments.append(SegmentCircle((sw_dot_r, 0), sw_dot_r))
-        self.segments.append(SegmentCircle((1-sw_dot_r, -.4), sw_dot_r))
-        self.segments.append(SegmentCircle((1-sw_dot_r, .4), sw_dot_r))
-        self.anchors['a'] = Point((0, 0))
-        self.anchors['b'] = Point((1, .4))
-        self.anchors['c'] = Point((1, -.4))
+
+        self.segments.append(SegmentCircle((sw_dot_r, 0), sw_dot_r, fill='bg', zorder=3))
+        self.segments.append(SegmentCircle((1-sw_dot_r, -.4), sw_dot_r, fill='bg', zorder=3))
+        self.segments.append(SegmentCircle((1-sw_dot_r, .4), sw_dot_r, fill='bg', zorder=3))
+        self.anchors['a'] = Point((sw_dot_r, 0))
+        self.anchors['b'] = Point((1-sw_dot_r, .4))
+        self.anchors['c'] = Point((1-sw_dot_r, -.4))
         if action == 'open':
             self.segments.append(SegmentArc((.35, 0), width=.5, height=.75,
                                             theta1=-10, theta2=70,
@@ -123,19 +124,19 @@ class SwitchDpst(Element):
         yofst = -1
         self.segments.append(Segment([(0, 0), gap, (sw_dot_r*2, .1),
                                       (.8, .45), gap, (1, 0)]))
-        self.segments.append(SegmentCircle((sw_dot_r, 0), sw_dot_r))
-        self.segments.append(SegmentCircle((1-sw_dot_r, 0), sw_dot_r))
+        self.segments.append(SegmentCircle((sw_dot_r, 0), sw_dot_r, fill='bg', zorder=3))
+        self.segments.append(SegmentCircle((1-sw_dot_r, 0), sw_dot_r, fill='bg', zorder=3))
         self.segments.append(Segment([(0, yofst), gap, (sw_dot_r*2, yofst+.1),
                                       (.8, yofst+.45), gap, (1, yofst)]))
-        self.segments.append(SegmentCircle((sw_dot_r, yofst), sw_dot_r))
-        self.segments.append(SegmentCircle((1-sw_dot_r, yofst), sw_dot_r))
+        self.segments.append(SegmentCircle((sw_dot_r, yofst), sw_dot_r, fill='bg', zorder=3))
+        self.segments.append(SegmentCircle((1-sw_dot_r, yofst), sw_dot_r, fill='bg', zorder=3))
         if link:
             self.segments.append(Segment([(0.5, yofst+.25),
                                           (0.5, 0.2)], ls=':'))
-        self.anchors['p1'] = (0, 0)
-        self.anchors['t1'] = (1, 0)
-        self.anchors['p2'] = (0, yofst)
-        self.anchors['t2'] = (1, yofst)
+        self.anchors['p1'] = (sw_dot_r, 0)
+        self.anchors['t1'] = (1-sw_dot_r, 0)
+        self.anchors['p2'] = (sw_dot_r, yofst)
+        self.anchors['t2'] = (1-sw_dot_r, yofst)
 
 
 class SwitchDpdt(Element):
@@ -157,23 +158,23 @@ class SwitchDpdt(Element):
         yofst = -1.4
         self.segments.append(Segment([(0, 0), gap, (sw_dot_r*2, .1),
                                       (.7, .25), gap, (1, .4)]))
-        self.segments.append(SegmentCircle((sw_dot_r, 0), sw_dot_r))
-        self.segments.append(SegmentCircle((1-sw_dot_r, -.4), sw_dot_r))
-        self.segments.append(SegmentCircle((1-sw_dot_r, .4), sw_dot_r))
+        self.segments.append(SegmentCircle((sw_dot_r, 0), sw_dot_r, fill='bg', zorder=3))
+        self.segments.append(SegmentCircle((1-sw_dot_r, -.4), sw_dot_r, fill='bg', zorder=3))
+        self.segments.append(SegmentCircle((1-sw_dot_r, .4), sw_dot_r, fill='bg', zorder=3))
         self.segments.append(Segment([(0, yofst), gap, (sw_dot_r*2, yofst+.1),
                                       (.7, yofst+.25), gap, (1, yofst+.4)]))
-        self.segments.append(SegmentCircle((sw_dot_r, yofst), sw_dot_r))
-        self.segments.append(SegmentCircle((1-sw_dot_r, yofst-.4), sw_dot_r))
-        self.segments.append(SegmentCircle((1-sw_dot_r, yofst+.4), sw_dot_r))
+        self.segments.append(SegmentCircle((sw_dot_r, yofst), sw_dot_r, fill='bg', zorder=3))
+        self.segments.append(SegmentCircle((1-sw_dot_r, yofst-.4), sw_dot_r, fill='bg', zorder=3))
+        self.segments.append(SegmentCircle((1-sw_dot_r, yofst+.4), sw_dot_r, fill='bg', zorder=3))
         if link:
             self.segments.append(Segment([(0.5, yofst+.25),
                                           (0.5, 0.2)], ls=':'))
-        self.anchors['p1'] = (0, 0)
-        self.anchors['t1'] = (1, .4)
-        self.anchors['t2'] = (1, -.4)
-        self.anchors['p2'] = (0, yofst)
-        self.anchors['t3'] = (1, yofst+.4)
-        self.anchors['t4'] = (1, yofst-.4)
+        self.anchors['p1'] = (sw_dot_r, 0)
+        self.anchors['t1'] = (1-sw_dot_r, .4)
+        self.anchors['t2'] = (1-sw_dot_r, -.4)
+        self.anchors['p2'] = (sw_dot_r, yofst)
+        self.anchors['t3'] = (1-sw_dot_r, yofst+.4)
+        self.anchors['t4'] = (1-sw_dot_r, yofst-.4)
 
 
 class SwitchReed(Element2Term):
