@@ -1,6 +1,6 @@
 from .flow import Box, RoundBox, Subroutine, Data, Start, Ellipse, Decision, Connect, Process, RoundProcess
 from .flow import Terminal, Circle, State, StateEnd
-from ..elements import Arrow, Arrowhead, Line, Dot, Arc2, Arc3, ArcZ, ArcN, ArcLoop
+from ..elements import Arrow, Arrowhead, Line, Dot, Wire, Arc2, Arc3, ArcZ, ArcN, ArcLoop
 
 
 from . import legacy
