@@ -89,11 +89,12 @@ class Segment:
             capstyle: Capstyle for the segment: 'butt', 'round', 'square', ('projecting')
             joinstyle: Joinstyle for the segment: 'round', 'miter', or 'bevel'
             fill: Color to fill if path is closed
-            arrow: Arrowhead specifier, such as '->', '<-', or '<->'
+            arrow: Arrowhead specifier, such as '->', '<-', '<->', '-o', etc.
             arrowwidth: Width of arrowhead
             arrowlength: Length of arrowhead
             clip: Bounding box to clip to
             zorder: Z-order for segment
+            visible: Show the segment when drawn
     '''
     def __init__(self, path: Sequence[XY],
                  color: str=None,
@@ -106,7 +107,8 @@ class Segment:
                  arrowwidth: float=0.15,
                  arrowlength: float=0.25,
                  clip: BBox=None,
-                 zorder: int=None):
+                 zorder: int=None,
+                 visible: bool=True):
         self.path: Sequence[XY] = [Point(p) for p in path]   # Untranformed path
         self.zorder = zorder
         self.color = color
@@ -119,6 +121,7 @@ class Segment:
         self.clip = clip
         self.capstyle = capstyle
         self.joinstyle = joinstyle
+        self.visible = visible
 
     def xform(self, transform, **style) -> 'Segment':
         ''' Return a new Segment that has been transformed
@@ -128,17 +131,19 @@ class Segment:
                 transform: Transformation to apply
                 style: Style parameters from Element to apply as default
         '''
-        params: dict[str, Any] = {'zorder': self.zorder,
-                                  'color': self.color,
-                                  'fill': self.fill,
-                                  'lw': self.lw,
-                                  'ls': self.ls,
-                                  'arrow': self.arrow,
-                                  'arrowwidth': self.arrowwidth,
-                                  'arrowlength': self.arrowlength,
-                                  'capstyle': self.capstyle,
-                                  'joinstyle': self.joinstyle}
-        style = {k: v for k, v in style.items() if k in params.keys()}
+        params: dict[str, Any] = {
+            'zorder': self.zorder if self.zorder is not None else style.get('zorder', None),
+            'color': self.color if self.color else style.get('color', None),
+            'fill': self.fill if self.fill is not None else style.get('fill', None),
+            'lw': self.lw if self.lw else style.get('lw', None),
+            'ls': self.ls if self.ls else style.get('ls', None),
+            'arrow': self.arrow,
+            'arrowwidth': self.arrowwidth,
+            'arrowlength': self.arrowlength,
+            'capstyle': self.capstyle if self.capstyle else style.get('capstyle', None),
+            'joinstyle': self.joinstyle if self.joinstyle else style.get('joinstyle', None),
+            'visible': self.visible}
+        style = {k: v for k, v in style.items() if params.get(k) is not None}
         params.update(style)
         return Segment(transform.transform_array(self.path), **params)
 
@@ -157,7 +162,7 @@ class Segment:
         ''' Reverse the path (flip horizontal about the center of the path) '''
         self.path = [util.mirrorx(p, centerx) for p in self.path[::-1]]
         if self.arrow:
-            self.arrow = self.arrow.translate(self.arrow.maketrans('<>', '><'))
+            self.arrow = self.arrow[::-1].translate(self.arrow.maketrans('<>', '><'))
 
     def doflip(self) -> None:
         ''' Vertically flip the element '''
@@ -171,6 +176,8 @@ class Segment:
                 transform: Transform to apply before drawing
                 style: Default style parameters
         '''
+        if not self.visible:
+            return
         path = transform.transform_array(self.path)
         linepath = list(path)
         zorder = self.zorder if self.zorder is not None else style.get('zorder', 2)
@@ -207,14 +214,38 @@ class Segment:
                  ls=ls, lw=lw, capstyle=capstyle, joinstyle=joinstyle,
                  clip=self.clip, zorder=zorder)
 
-        if self.arrow and '<' in self.arrow:
-            theta = math.degrees(math.atan2(path[0].y-path[1].y, path[0].x-path[1].x))
-            fig.arrow(path[0], theta, color=color, zorder=zorder, clip=self.clip,
-                      arrowlength=self.arrowlength, arrowwidth=self.arrowwidth, lw=1)
-        if self.arrow and '>' in self.arrow:
-            theta = math.degrees(math.atan2(path[-1].y-path[-2].y, path[-1].x-path[-2].x))
-            fig.arrow(path[-1], theta, color=color, zorder=zorder, clip=self.clip,
-                      arrowlength=self.arrowlength, arrowwidth=self.arrowwidth, lw=1)
+        if self.arrow:
+            if '<' in self.arrow:
+                theta = math.degrees(math.atan2(path[0].y-path[1].y, path[0].x-path[1].x))
+                fig.arrow(path[0], theta, color=color, zorder=zorder, clip=self.clip,
+                          arrowlength=self.arrowlength, arrowwidth=self.arrowwidth, lw=1)
+            elif self.arrow.startswith('o'):
+                fig.circle(path[0], self.arrowwidth/2, color=color, fill=color, lw=lw,
+                           clip=self.clip, zorder=zorder)
+            elif self.arrow.startswith('|'):
+                theta = math.atan2(path[0].y-path[1].y, path[0].x-path[1].x) + math.pi/2
+                tailx = (path[0].x + self.arrowwidth/2 * math.cos(theta),
+                         path[0].x - self.arrowwidth/2 * math.cos(theta))
+                taily = (path[0].y + self.arrowwidth/2 * math.sin(theta),
+                         path[0].y - self.arrowwidth/2 * math.sin(theta))
+                fig.plot(tailx, taily, color=color, fill=fill, capstyle=capstyle,
+                         joinstyle=joinstyle, clip=self.clip, zorder=zorder)
+
+            if '>' in self.arrow:
+                theta = math.degrees(math.atan2(path[-1].y-path[-2].y, path[-1].x-path[-2].x))
+                fig.arrow(path[-1], theta, color=color, zorder=zorder, clip=self.clip,
+                          arrowlength=self.arrowlength, arrowwidth=self.arrowwidth, lw=1)
+            elif self.arrow.endswith('o'):
+                fig.circle(path[-1], self.arrowwidth/2, color=color, fill=color, lw=lw,
+                            clip=self.clip, zorder=zorder)
+            elif self.arrow.endswith('|'):
+                theta = math.atan2(path[-1].y-path[-2].y, path[-1].x-path[-2].x) + math.pi/2
+                tailx = (path[-1].x + self.arrowwidth/2 * math.cos(theta),
+                         path[-1].x - self.arrowwidth/2 * math.cos(theta))
+                taily = (path[-1].y + self.arrowwidth/2 * math.sin(theta),
+                         path[-1].y - self.arrowwidth/2 * math.sin(theta))
+                fig.plot(tailx, taily, color=color, fill=fill, capstyle=capstyle,
+                         joinstyle=joinstyle, clip=self.clip, zorder=zorder)
 
 
 class SegmentText:
@@ -231,8 +262,10 @@ class SegmentText:
             color: Color for this segment
             fontsize: Font size
             font: Font name/family
+            mathfont: Math font name/family
             clip: Bounding box to clip to
             zorder: Z-order for segment
+            visible: Show the segment when drawn
     '''
     def __init__(self, pos: Sequence[float], label: str,
                  align: Align=None,
@@ -241,18 +274,22 @@ class SegmentText:
                  color: str=None,
                  fontsize: float=14,
                  font: str=None,
+                 mathfont: str=None,
                  clip: BBox=None,
-                 zorder: int=None):
+                 zorder: int=None,
+                 visible: bool=True):
         self.xy = pos
         self.text = label
         self.align = align
         self.font = font
+        self.mathfont = mathfont
         self.fontsize = fontsize
         self.color = color
         self.rotation = rotation
         self.rotation_mode = rotation_mode
         self.clip = clip
         self.zorder = zorder
+        self.visible = visible
 
     def doreverse(self, centerx: float) -> None:
         ''' Reverse the path (flip horizontal about the centerx point) '''
@@ -270,16 +307,19 @@ class SegmentText:
                 transform: Transformation to apply
                 style: Style parameters from Element to apply as default
         '''
-        params: dict[str, Any] = {'align': self.align,
-                                  'font': self.font,
-                                  'fontsize': self.fontsize,
-                                  'color': self.color,
-                                  'rotation': self.rotation,
-                                  'rotation_mode': self.rotation_mode,
-                                  'clip': self.clip,
-                                  'zorder': self.zorder}
+        params: dict[str, Any] = {
+            'align': self.align if self.align else style.get('align', None),
+            'font': self.font if self.font else style.get('font', None),
+            'mathfont': self.mathfont if self.mathfont else style.get('mathfont', None),
+            'fontsize': self.fontsize if self.fontsize else style.get('fontsize', style.get('size', None)),
+            'color': self.color if self.color else style.get('color', None),
+            'rotation': self.rotation if self.rotation else style.get('rotation', None),
+            'rotation_mode': self.rotation_mode if self.rotation_mode else style.get('rotation_mode', None),
+            'clip': self.clip,
+            'zorder': self.zorder if self.zorder is not None else style.get('zorder', None),
+            'visible': self.visible}
 
-        style = {k: v for k, v in style.items() if k in params.keys()}
+        style = {k: v for k, v in style.items() if params.get(k) is not None}
         params.update(style)
         return SegmentText(transform.transform(self.xy),
                            self.text, **params)
@@ -318,17 +358,20 @@ class SegmentText:
                 transform: Transform to apply before drawing
                 style: Default style parameters
         '''
+        if not self.visible:
+            return
         xy = transform.transform(self.xy)
         color = self.color if self.color else style.get('color', 'black')
         fontsize = self.fontsize if self.fontsize else style.get('fontsize', style.get('size', 14))
         font = self.font if self.font else style.get('font', 'sans-serif')
+        mathfont = self.mathfont if self.mathfont else style.get('mathfont', None)
         align = self.align if self.align else style.get('align', ('center', 'center'))
         rotation = self.rotation if self.rotation else style.get('rotation', 0)
         rotmode = self.rotation_mode if self.rotation_mode else style.get('rotation_mode', 'anchor')
         zorder = self.zorder if self.zorder is not None else style.get('zorder', 3)
 
         fig.text(self.text, xy[0], xy[1],
-                 color=color, fontsize=fontsize, fontfamily=font,
+                 color=color, fontsize=fontsize, fontfamily=font, mathfont=mathfont,
                  rotation=rotation, rotation_mode=rotmode,
                  halign=align[0], valign=align[1], clip=self.clip, zorder=zorder)
 
@@ -349,6 +392,7 @@ class SegmentPoly:
             joinstyle: Joinstyle for the segment: 'round', 'miter', or 'bevel'
             clip: Bounding box to clip to
             zorder: Z-order for segment
+            visible: Show the segment when drawn
     '''
     def __init__(self, verts: Sequence[Sequence[float]],
                  closed: bool=True,
@@ -361,7 +405,8 @@ class SegmentPoly:
                  joinstyle: Joinstyle=None,
                  capstyle: Capstyle=None,
                  clip: BBox=None,
-                 zorder: int=None):
+                 zorder: int=None,
+                 visible: bool=True):
         self.verts = verts
         self.closed = closed
         self.cornerradius = cornerradius
@@ -374,6 +419,7 @@ class SegmentPoly:
         self.lw = lw
         self.ls = ls
         self.clip = clip
+        self.visible = visible
 
     def doreverse(self, centerx: float) -> None:
         ''' Reverse the path (flip horizontal about the centerx point) '''
@@ -391,16 +437,18 @@ class SegmentPoly:
                 transform: Transformation to apply
                 style: Style parameters from Element to apply as default
         '''
-        params: dict[str, Any] = {'color': self.color,
-                                  'fill': self.fill,
-                                  'joinstyle': self.joinstyle,
-                                  'capstyle': self.capstyle,
-                                  'lw': self.lw,
-                                  'ls': self.ls,
-                                  'cornerradius': self.cornerradius,
-                                  'clip': self.clip,
-                                  'zorder': self.zorder}
-        style = {k: v for k, v in style.items() if k in params.keys()}
+        params: dict[str, Any] = {
+            'color': self.color if self.color else style.get('color', None),
+            'fill': self.fill if self.fill is not None else style.get('fill', None),
+            'joinstyle': self.joinstyle if self.joinstyle else style.get('joinstyle', None),
+            'capstyle': self.capstyle if self.capstyle else style.get('capstyle', None),
+            'lw': self.lw if self.lw else style.get('lw', None),
+            'ls': self.ls if self.ls else style.get('ls', None),
+            'cornerradius': self.cornerradius,
+            'clip': self.clip,
+            'zorder': self.zorder if self.zorder is not None else style.get('zorder', None),
+            'visible': self.visible}
+        style = {k: v for k, v in style.items() if params.get(k) is not None}
         params.update(style)
         return SegmentPoly(transform.transform_array(self.verts), **params)
 
@@ -422,6 +470,8 @@ class SegmentPoly:
                 transform: Transform to apply before drawing
                 style: Default style parameters
         '''
+        if not self.visible:
+            return
         fill = self.fill if self.fill is not None else style.get('fill', None)
         color = self.color if self.color else style.get('color', 'black')
         if fill is not None:
@@ -460,6 +510,7 @@ class SegmentCircle:
             clip: Bounding box to clip to
             zorder: Z-order for segment
             ref: Flip reference ['start', 'end', None].
+            visible: Show the segment when drawn
     '''
     def __init__(self, center: Sequence[float], radius: float,
                  color: str=None,
@@ -468,7 +519,8 @@ class SegmentCircle:
                  fill: bool | str | None=None,
                  clip: BBox=None,
                  zorder: int=None,
-                 ref: EndRef=None):
+                 ref: EndRef=None,
+                 visible: bool=True):
         self.center = center
         self.radius = radius
         self.zorder = zorder
@@ -477,6 +529,7 @@ class SegmentCircle:
         self.lw = lw
         self.ls = ls
         self.clip = clip
+        self.visible = visible
 
         # Reference for adding things AFTER lead extensions
         self.endref = ref
@@ -498,17 +551,19 @@ class SegmentCircle:
                 transform: Transformation to apply
                 style: Style parameters from Element to apply as default
         '''
-        params: dict[str, Any] = {'zorder': self.zorder,
-                                  'color': self.color,
-                                  'fill': self.fill,
-                                  'lw': self.lw,
-                                  'ls': self.ls,
-                                  'clip': self.clip,
-                                  'ref': self.endref}
-        style = {k: v for k, v in style.items() if k in params.keys()}
+        params: dict[str, Any] = {
+            'zorder': self.zorder if self.zorder is not None else style.get('zorder', None),
+            'color': self.color if self.color else style.get('color', None),
+            'fill': self.fill if self.fill is not None else style.get('fill', None),
+            'lw': self.lw if self.lw else style.get('lw', None),
+            'ls': self.ls if self.ls else style.get('ls', None),
+            'clip': self.clip,
+            'ref': self.endref,
+            'visible': self.visible}
+        style = {k: v for k, v in style.items() if params.get(k) is not None}
         params.update(style)
         return SegmentCircle(transform.transform(self.center),
-                             self.radius, **params)
+                             self.radius*transform.zoom, **params)
 
     def get_bbox(self) -> BBox:
         ''' Get bounding box (untransformed)
@@ -530,6 +585,8 @@ class SegmentCircle:
                 transform: Transform to apply before drawing
                 style: Default style parameters
         '''
+        if not self.visible:
+            return
         center = transform.transform(self.center)
         radius = transform.zoom * self.radius
         zorder = self.zorder if self.zorder is not None else style.get('zorder', 1)
@@ -567,6 +624,7 @@ class SegmentBezier:
             arrowlength: Length of arrowhead
             clip: Bounding box to clip to
             zorder: Z-order for segment
+            visible: Show the segment when drawn
     '''
     def __init__(self, p: Sequence[XY],
                  color: str=None,
@@ -575,9 +633,10 @@ class SegmentBezier:
                  capstyle: Capstyle=None,
                  arrow: str=None,
                  arrowlength: float=.25,
-                 arrowwidth: float=.2,
+                 arrowwidth: float=.15,
                  clip: BBox=None,
-                 zorder: int=None):
+                 zorder: int=None,
+                 visible: bool=True):
         self.p = [Point(pi) for pi in p]
         self.arrow = arrow
         self.color = color
@@ -588,12 +647,13 @@ class SegmentBezier:
         self.arrowwidth = arrowwidth
         self.clip = clip
         self.zorder = zorder
+        self.visible = visible
 
     def doreverse(self, centerx: float) -> None:
         ''' Reverse the path (flip horizontal about the centerx point) '''
         self.p = [Point(util.mirrorx(p, centerx)) for p in self.p]
         if self.arrow:
-            self.arrow = self.arrow.translate(self.arrow.maketrans('<>', '><'))
+            self.arrow = self.arrow[::-1].translate(self.arrow.maketrans('<>', '><'))
 
     def doflip(self) -> None:
         ''' Vertically flip the element '''
@@ -607,16 +667,18 @@ class SegmentBezier:
                 transform: Transformation to apply
                 style: Style parameters from Element to apply as default
         '''
-        params: dict[str, Any] = {'color': self.color,
-                                  'lw': self.lw,
-                                  'ls': self.ls,
-                                  'capstyle': self.capstyle,
-                                  'arrow': self.arrow,
-                                  'arrowlength': self.arrowlength,
-                                  'arrowwidth': self.arrowwidth,
-                                  'clip': self.clip,
-                                  'zorder': self.zorder}
-        style = {k: v for k, v in style.items() if k in params.keys()}
+        params: dict[str, Any] = {
+            'color': self.color if self.color else style.get('color', None),
+            'lw': self.lw if self.lw else style.get('lw', None),
+            'ls': self.ls if self.ls else style.get('ls', None),
+            'capstyle': self.capstyle if self.capstyle else style.get('capstyle', None),
+            'arrow': self.arrow,
+            'arrowlength': self.arrowlength,
+            'arrowwidth': self.arrowwidth,
+            'clip': self.clip,
+            'zorder': self.zorder if self.zorder is not None else style.get('zorder', None),
+            'visible': self.visible}
+        style = {k: v for k, v in style.items() if params.get(k) is not None}
         params.update(style)
         return SegmentBezier(transform.transform_array(self.p), **params)
 
@@ -639,6 +701,8 @@ class SegmentBezier:
                 transform: Transform to apply before drawing
                 style: Default style parameters
         '''
+        if not self.visible:
+            return
         p = transform.transform_array(self.p)
         zorder = self.zorder if self.zorder is not None else style.get('zorder', 1)
         color = self.color if self.color else style.get('color', 'black')
@@ -666,6 +730,7 @@ class SegmentArc:
             ls: Line style for the segment
             clip: Bounding box to clip to
             zorder: Z-order for segment
+            visible: Show the segment when drawn
     '''
     def __init__(self, center: Sequence[float],
                  width: float, height: float,
@@ -676,7 +741,8 @@ class SegmentArc:
                  lw: float=None,
                  ls: Linestyle=None,
                  clip: BBox=None,
-                 zorder: int=None):
+                 zorder: int=None,
+                 visible: bool=True):
         self.center = center
         self.width = width
         self.height = height
@@ -689,6 +755,7 @@ class SegmentArc:
         self.ls = ls
         self.clip = clip
         self.zorder = zorder
+        self.visible = visible
 
     def doreverse(self, centerx: float) -> None:
         ''' Reverse the path (flip horizontal about the centerx point) '''
@@ -711,12 +778,14 @@ class SegmentArc:
                 style: Style parameters from Element to apply as default
         '''
         angle = self.angle + transform.theta
-        params: dict[str, Any] = {'color': self.color,
-                                  'lw': self.lw,
-                                  'ls': self.ls,
-                                  'clip': self.clip,
-                                  'zorder': self.zorder}
-        style = {k: v for k, v in style.items() if k in params.keys()}
+        params: dict[str, Any] = {
+            'color': self.color if self.color else style.get('color', None),
+            'lw': self.lw if self.lw else style.get('lw', None),
+            'ls': self.ls if self.ls else style.get('ls', None),
+            'clip': self.clip,
+            'zorder': self.zorder if self.zorder is not None else style.get('zorder', None),
+            'visible': self.visible}
+        style = {k: v for k, v in style.items() if params.get(k) is not None}
         params.update(style)
         return SegmentArc(transform.transform(self.center),
                           self.width*transform.zoom, self.height*transform.zoom, angle=angle,
@@ -756,6 +825,8 @@ class SegmentArc:
                 transform: Transform to apply before drawing
                 style: Default style parameters
         '''
+        if not self.visible:
+            return
         center = transform.transform(self.center)
         angle = self.angle + transform.theta
 
